==> haskell-comonad-5.0.4-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-G74MNGthp8MIbDjNAMuYxQ
key: comonad-5.0.4-G74MNGthp8MIbDjNAMuYxQ
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: 6066a8b25d542e863756d32fb8ed7569
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-G74MNGthp8MIbDjNAMuYxQ
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    distributive-0.6-8yrDTpYI7z3GBlcGm7xBun
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             distributive-0.6-8yrDTpYI7z3GBlcGm7xBun=a079785a4964933ed2c7b4e8ef9f7443
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-comonad-5.0.4-12-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-comonad.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: comonad
version: 5.0.4
id: comonad-5.0.4-DMINZ0aMd8oFIhjlIqJSEs
key: comonad-5.0.4-DMINZ0aMd8oFIhjlIqJSEs
license: BSD-3-Clause
copyright: Copyright (C) 2008-2014 Edward A. Kmett,
           Copyright (C) 2004-2008 Dave Menendez
maintainer: Edward A. Kmett <ekmett@gmail.com>
author: Edward A. Kmett
stability: provisional
homepage: http://github.com/ekmett/comonad/
synopsis: Comonads
description:
    Comonads.
category: Control, Comonads
abi: fef355d343d551e29f05ec96a9889e51
exposed: True
exposed-modules:
    Control.Comonad Control.Comonad.Env Control.Comonad.Env.Class
    Control.Comonad.Hoist.Class Control.Comonad.Identity
    Control.Comonad.Store Control.Comonad.Store.Class
    Control.Comonad.Traced Control.Comonad.Traced.Class
    Control.Comonad.Trans.Class Control.Comonad.Trans.Env
    Control.Comonad.Trans.Identity Control.Comonad.Trans.Store
    Control.Comonad.Trans.Traced Data.Functor.Composition
import-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
library-dirs: /usr/lib/ghc-8.4.3/site-local/comonad-5.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/comonad-5.0.4
hs-libraries: HScomonad-5.0.4-DMINZ0aMd8oFIhjlIqJSEs
depends:
    base-4.11.1.0 tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO
    transformers-0.5.5.0
    transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W
    containers-0.5.11.0 contravariant-1.5-5VBqEYOPGpyDW8QIali4BA
    distributive-0.6-5IIrIvROWijDhzEpafTMUk
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=92d44612a64675b8cba7ce44e507a395
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             transformers-compat-0.6.2-EZ0ZvADLUlc4V8RuKaJX5W=8fe746d31ebcf312c14c2777ca0f137c
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             contravariant-1.5-5VBqEYOPGpyDW8QIali4BA=02e9ed60b8864056c6af15ff76a262ef
             distributive-0.6-5IIrIvROWijDhzEpafTMUk=c989dcfe9e7c3d052b4dd45341fdc752
haddock-interfaces: /usr/share/doc/haskell-comonad/html/comonad.haddock
haddock-html: /usr/share/doc/haskell-comonad/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
